==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1IngressSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1IngressSpecFluent<A extends V1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1IngressBackend getBackend();
    public V1beta1IngressBackend buildBackend();
    public A withBackend(V1beta1IngressBackend backend);
    public Boolean hasBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(V1beta1IngressBackend item);
    public V1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(V1beta1IngressBackend item);
    public A addToRules(int index,V1beta1IngressRule item);
    public A setToRules(int index,V1beta1IngressRule item);
    public A addToRules(V1beta1IngressRule... items);
    public A addAllToRules(Collection<V1beta1IngressRule> items);
    public A removeFromRules(V1beta1IngressRule... items);
    public A removeAllFromRules(Collection<V1beta1IngressRule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1IngressRule> getRules();
    public List<V1beta1IngressRule> buildRules();
    public V1beta1IngressRule buildRule(int index);
    public V1beta1IngressRule buildFirstRule();
    public V1beta1IngressRule buildLastRule();
    public V1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1IngressRuleBuilder> predicate);
    public A withRules(List<V1beta1IngressRule> rules);
    public A withRules(V1beta1IngressRule... rules);
    public Boolean hasRules();
    public V1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public V1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(V1beta1IngressRule item);
    public V1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,V1beta1IngressRule item);
    public V1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public V1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public V1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public V1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,V1beta1IngressTLS item);
    public A setToTls(int index,V1beta1IngressTLS item);
    public A addToTls(V1beta1IngressTLS... items);
    public A addAllToTls(Collection<V1beta1IngressTLS> items);
    public A removeFromTls(V1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<V1beta1IngressTLS> items);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1IngressTLS> getTls();
    public List<V1beta1IngressTLS> buildTls();
    public V1beta1IngressTLS buildTl(int index);
    public V1beta1IngressTLS buildFirstTl();
    public V1beta1IngressTLS buildLastTl();
    public V1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<V1beta1IngressTLSBuilder> predicate);
    public A withTls(List<V1beta1IngressTLS> tls);
    public A withTls(V1beta1IngressTLS... tls);
    public Boolean hasTls();
    public V1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public V1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(V1beta1IngressTLS item);
    public V1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,V1beta1IngressTLS item);
    public V1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public V1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public V1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public V1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<V1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressBackendFluent<V1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressRuleFluent<V1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressTLSFluent<V1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1IngressSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1IngressSpecFluent<A extends V1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1IngressBackend getBackend();
    public V1beta1IngressBackend buildBackend();
    public A withBackend(V1beta1IngressBackend backend);
    public Boolean hasBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(V1beta1IngressBackend item);
    public V1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public V1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(V1beta1IngressBackend item);
    public A addToRules(int index,V1beta1IngressRule item);
    public A setToRules(int index,V1beta1IngressRule item);
    public A addToRules(V1beta1IngressRule... items);
    public A addAllToRules(Collection<V1beta1IngressRule> items);
    public A removeFromRules(V1beta1IngressRule... items);
    public A removeAllFromRules(Collection<V1beta1IngressRule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1IngressRule> getRules();
    public List<V1beta1IngressRule> buildRules();
    public V1beta1IngressRule buildRule(int index);
    public V1beta1IngressRule buildFirstRule();
    public V1beta1IngressRule buildLastRule();
    public V1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1IngressRuleBuilder> predicate);
    public A withRules(List<V1beta1IngressRule> rules);
    public A withRules(V1beta1IngressRule... rules);
    public Boolean hasRules();
    public V1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public V1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(V1beta1IngressRule item);
    public V1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,V1beta1IngressRule item);
    public V1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public V1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public V1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public V1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,V1beta1IngressTLS item);
    public A setToTls(int index,V1beta1IngressTLS item);
    public A addToTls(V1beta1IngressTLS... items);
    public A addAllToTls(Collection<V1beta1IngressTLS> items);
    public A removeFromTls(V1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<V1beta1IngressTLS> items);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1IngressTLS> getTls();
    public List<V1beta1IngressTLS> buildTls();
    public V1beta1IngressTLS buildTl(int index);
    public V1beta1IngressTLS buildFirstTl();
    public V1beta1IngressTLS buildLastTl();
    public V1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<V1beta1IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(io.kubernetes.client.fluent.Predicate<V1beta1IngressTLSBuilder> predicate);
    public A withTls(List<V1beta1IngressTLS> tls);
    public A withTls(V1beta1IngressTLS... tls);
    public Boolean hasTls();
    public V1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public V1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(V1beta1IngressTLS item);
    public V1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,V1beta1IngressTLS item);
    public V1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public V1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public V1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public V1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<V1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressBackendFluent<V1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressRuleFluent<V1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1IngressTLSFluent<V1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}
